@@ -1,5 +1,6 @@
 import argparse
 import os
+import pprint
 import subprocess
 import sys
 
@@ -164,7 +165,7 @@ def start(arguments):
     dicts = {}
     dicts.update(newdct)
     dicts.update(data_params)
-    print("Final parameters for the run are: {}".format(dicts))
+    pprint.pprint("Final parameters for the run are: {}".format(dicts))
 
 
 def parse_args(args):
